FIFOProcessor

Struct FIFOProcessor 

#[repr(C)]
pub struct FIFOProcessor { pub _base: FIFOSamplePipe, pub output: *mut FIFOSamplePipe, }
Base-class for sound processing routines working in FIFO principle. With this base class it’s easy to implement sound processing stages that can be chained together, so that samples that are fed into beginning of the pipe automatically go through all the processing stages.

When samples are input to this class, they’re first processed and then put to the FIFO pipe that’s defined as output of this class. This output pipe can be either other processing stage or a FIFO sample buffer.

Fields

_base: FIFOSamplePipeoutput: *mut FIFOSamplePipe

Internal pipe where processed samples are put.