FIFOSampleBuffer

Struct FIFOSampleBuffer 

#[repr(C)]
pub struct FIFOSampleBuffer { pub _base: FIFOSamplePipe, pub buffer: *mut SAMPLETYPE, pub bufferUnaligned: *mut SAMPLETYPE, pub sizeInBytes: uint, pub samplesInBuffer: uint, pub channels: uint, pub bufferPos: uint, }
Sample buffer working in FIFO (first-in-first-out) principle. The class takes care of storage size adjustment and data moving during input/output operations.

Notice that in case of stereo audio, one sample is considered to consist of both channel data.

Fields

_base: FIFOSamplePipebuffer: *mut SAMPLETYPE

Sample buffer.

bufferUnaligned: *mut SAMPLETYPEsizeInBytes: uint

Sample buffer size in bytes

samplesInBuffer: uint

How many samples are currently in buffer.

channels: uint

Channels, 1=mono, 2=stereo.

bufferPos: uint

Current position pointer to the buffer. This pointer is increased when samples are removed from the pipe so that it’s necessary to actually rewind buffer (move data) only new data when is put to the pipe.

Implementations

Source

impl FIFOSampleBuffer

pub unsafe fn ptrEnd(&mut self, slackCapacity: uint) -> *mut SAMPLETYPE

pub unsafe fn setChannels(&mut self, numChannels: c_int)

pub unsafe fn addSilent(&mut self, nSamples: uint)

pub unsafe fn new(numChannels: c_int) -> Self